assert_ipc_called_with

Function assert_ipc_called_with 

pub fn assert_ipc_called_with(log: &Value, command: &str, expected_args: &Value)
Assert that a specific IPC command was called with the given arguments.

Uses partial matching — the expected args only need to be a subset of actual args.

Panics

Panics if the command was not called with matching arguments.

Examples

use serde_json::json;

let log = json!([{"command": "save_settings", "args": {"theme": "dark", "lang": "en"}}]);
victauri_test::assert_ipc_called_with(&log, "save_settings", &json!({"theme": "dark"}));