pub struct VerifyReport {
pub results: Vec<CheckResult>,
}Expand description
Collection of check results from a verify() run.
Fields
results: Vec<CheckResult>Individual check results in order.
Implementations
Sourceimpl VerifyReport
impl VerifyReport
Sourcepub fn all_passed(&self) -> bool
pub fn all_passed(&self) -> bool
Returns true if all checks passed.
Sourcepub fn failures(&self) -> Vec<&CheckResult>
pub fn failures(&self) -> Vec<&CheckResult>
Returns only the failed checks.
Sourcepub fn to_junit(&self, suite_name: &str, duration: Duration) -> JunitReport
pub fn to_junit(&self, suite_name: &str, duration: Duration) -> JunitReport
Converts this report to a JUnit XML JunitReport.
Sourcepub fn assert_all_passed(&self)
pub fn assert_all_passed(&self)
Panics with a formatted report if any check failed.
Panics
Panics if any check in the report did not pass.