pub fn assert_json_eq(value: &Value, pointer: &str, expected: &Value)Expand description
Assert that a JSON value at the given pointer equals the expected value.
Panics
Panics if the value at pointer is missing or does not equal expected.
Examples
use serde_json::json;
let state = json!({"visible": true, "title": "My App"});
victauri_test::assert_json_eq(&state, "/visible", &json!(true));
victauri_test::assert_json_eq(&state, "/title", &json!("My App"));